@@ -559,7 +559,7 @@ class ER:
                 continue
 
             if debugging:
-                print(f" » testing {n1.get('label', '')}:")
+                print(f" » testing node '{n1.get('label', '')}':")
 
             distancePerProperty = scores['missing_property'][n1.get('nodeType', NodeType.NOT_SPECIFIED)]
 
@@ -571,7 +571,7 @@ class ER:
             if not otherGraphHasObjectBool:
                 # not found.
                 if debugging:
-                    print(f"   ✗ {scores['missing_object']:+.2f}, {n1.get('nodeType', NodeType.NOT_SPECIFIED)} '{n1.get('label', '')}' doesn't exist in other graph")
+                    print(f"   ❌ {scores['missing_object']:+.2f}, {n1.get('nodeType', NodeType.NOT_SPECIFIED)} '{n1.get('label', '')}' doesn't exist in other graph")
                 dist += scores['missing_object']
 
                 # additionally substract points for missing node attributes
@@ -581,7 +581,7 @@ class ER:
                     for y in x:
                         distancePerProperty = scores['missing_property'][str(NodeType.ATTRIBUTE)]
                         if debugging:
-                            print(f"   ✗ {distancePerProperty:+.2f}, missing {NodeType.ATTRIBUTE} '{y.get('label', '')}' ")
+                            print(f"   ❌ {distancePerProperty:+.2f}, missing {NodeType.ATTRIBUTE} '{y.get('label', '')}' ")
                         dist += distancePerProperty
             else:
                 # node exists, check equality and compare
@@ -595,7 +595,7 @@ class ER:
                     n2 = otherGraph.get_rel_adv(n1)
                     #if debugging: print(f"   found {n2['label']}")
                     if n2 == False:
-                        if debugging: print(f" cannot get relation {n1['label']} for comparison ")
+                        if debugging: print(f" ❌ relation '{n1['label']}' not found in checked graph ")
                         dist += scores['missing_object']
                         continue
                 else:
@@ -690,7 +690,7 @@ class ER:
                 # is attribute missing?
                 if not otherGraph.has_attr(localAttr.get('label', '')):
                     if debugging:
-                        print(f"   ✗ {distancePerProperty:+.2f}, missing {NodeType.ATTRIBUTE} '{localAttr.get('label', '')}' ")
+                        print(f"   ❌ {distancePerProperty:+.2f}, missing {NodeType.ATTRIBUTE} '{localAttr.get('label', '')}' ")
                     localDist += distancePerProperty
                 else:
                     # exists but check params (isWeak etc.)
@@ -700,7 +700,7 @@ class ER:
                         if compare < 0.8:
                             if (self.debug): print(f"compare attrs: '{value}' with '{otherAttr[key]}' @ {compare*100:.2f}%")
                             if debugging:
-                                print(f"   ✗ {distancePerProperty:+.2f}, mismatch@{key}: {value} != {otherAttr[key]} ")
+                                print(f"   ❌ {distancePerProperty:+.2f}, mismatch@{key}: {value} != {otherAttr[key]} ")
                             localDist += distancePerProperty
 
         # compare node properties (isWeak etc.)
@@ -720,7 +720,7 @@ class ER:
             #if debugging: print([thisNode, otherNode])
             if not self.__compare_node_properties(thisNode, otherNode, k, debugging):
                 if debugging:
-                    print(f"   ✗ {distancePerProperty:+.2f}, property mismatch")
+                    print(f"   ❌ {distancePerProperty:+.2f}, property mismatch")
                 localDist += distancePerProperty
             else:
                 continue
